accuracy_comprehension <-
  function(formula = ~ Lexeme + Person + Number + Tense + Voice + Mood,
           md = m, 
           data = latin, 
           cor = TRUE,
           epsilon = 0.05) {

    classes = all.vars(formula)

    dfr = data.frame(form = rep("x", nrow(data)),
                     r = rep(0, nrow(data)),
                     stringsAsFactors = FALSE)
    for (cl in classes) {
      dfr[,cl] = rep("x", nrow(data))
    }
    for (i in 1:nrow(data)) {
      # semantic_neighbors returns a data frame with neighbors on rows
      # the closest neighbor with the highest correlation is on row 1
      # this row is inserted in dfr
      sn = semantic_neighbors(word = data$Word[i], 
                                   data = data, 
                                   n = 6, 
                                   md = md,
                                   cor = cor)
      dfr[i,] = sn[1,c("form", "r", classes)]
    }
    dfr$target = data$Word
    
    dfr$correct = dfr$form==dfr$target
    dfr$positions = as.numeric(rownames(dfr))
    
    acc = sum(dfr$correct)/nrow(dfr)
 
    return(list(dfr=dfr, acc=acc, correlation=cor))
  }
