learn_mappings <-
  function(formula=~ Lexeme + Person + Number + Tense + Voice + Mood, 
           data=latin, 
           grams=3, 
           stdev_inflectional_semantic_vectors=4,
           seed_for_S=217) {
    
    
    ms3 = make_C_and_T_matrices(formula=formula, data=data, grams=grams)
    
    set.seed(seed_for_S)
    S = semantic_space(formula = formula, 
                       data=data, 
                       with_semantic_vectors = TRUE, 
                       with_mvrnorm = FALSE,
                       stdev_for_inflectional_semantic_vectors=
                         stdev_inflectional_semantic_vectors,
                       nrows=nrow(ms3$matrices$C),
                       ncols=ncol(ms3$matrices$C))

    C = ms3$matrices$C

    # understanding
    Hcomp = C %*% MASS::ginv(t(C)%*%C) %*% t(C)
    Shat = Hcomp%*%S
    Bcomp = MASS::ginv(t(C)%*%C) %*% t(C) %*% S
    
    # speaking
    Hprod = S%*%MASS::ginv(t(S)%*%S)%*%t(S)
    Bprod = MASS::ginv(t(S)%*%S)%*%t(S)%*%C
    Chat = Hprod %*% C
    
    gsu = graph_setup(ms3$datastructures$nCues, 
                      ms3$datastructures$Cues, 
                      ms3$datastructures$uniqueCues)
    am = gsu$am        # the adjacency matrix
    am.g = gsu$am.g
    
    res = list(
      am = am,
      am.g = am.g,
      C=C,
      S=S,
      Shat=Shat,
      Bcomp=Bcomp,
      Bprod=Bprod,
      Chat=Chat,
      ms3=ms3
    )
  }
