long_cycles <-
function(i=1,                  # index in dataset of the word evaluated
         Chat,                 # predicted form matrix C
         am,                   # adjacency matrix of full dataset
         am.g,                 # graph object of am
         Cues,                 # list with for each word its n-grams
         grams=3) {

  # extract all simple paths starting with the word's initial triphone
  paths = igraph::all_simple_paths(am.g, from=Cues[[i]][1])

  longCycles=list()
  cnt = 0
  for (m in 1:length(paths)) {  # for each simple path
    v = paths[[m]]
    v = colnames(am)[v]  # the path is now a vector of n-grams
    tri = v[length(v)]   # the last n-gram
    # search for n-grams earlier in the path that the last n-gram
    # could link back to
    candidates = paste(rep(substr(tri, 2, grams), length(v)-2), 
                       substr(v[2:(length(v)-1)], 1, 1),
                       sep="")
    # make sure the candidate vertices are attested in the dataset
    candidates = candidates[candidates %in% colnames(am)]
    # and if so also make sure that the relevant edge exists as well
    if (length(candidates) > 0) {
      candidates = candidates[am[tri,candidates]==1]
    }
    # if there are still candidates left
    if (length(candidates) > 0) {
      for (k in 1:length(candidates)) {  # loop over the candidates
        if (candidates[k] %in% v) {  # extra check that all is sane
          # calculate edgeWeights up to and including the candidate
          edgeWeights = c(Chat[i,][v], Chat[i,candidates[k]])
          names(edgeWeights) = c(v, candidates[k])
          # now we can use all_simple_paths again to calculate all possible
          # continuations from the candidate
          remainingPaths = igraph::all_simple_paths(am.g, from=candidates[k])
          newPaths = list()
          kk=0
          for (ii in 1:length(remainingPaths)) {  # loop over these new paths
            # make the new, complete path
            vv = c(v, colnames(am)[remainingPaths[[ii]]])
            if (substr(vv[length(vv)], 3, 3)=="#") {  # if this path has final n-gram
              ww = Chat[i,][vv]  # extract path supports from Chat
              names(ww)=vv       # add names of the vertices
              if (sum(ww < 0) == 0) {  # if there are no negative path supports anywhere
                kk=kk+1                # add this weights+path information to list newPaths
                newPaths[[kk]] = ww
              }
            }
          }

          if (length(newPaths) > 0) {
            cnt = cnt+1
            #longCycles[[cnt]] = list(i, v, candidates, edgeWeights, newPaths)
            longCycles[[cnt]] = newPaths
          } 
        }
      }
    } 
  }
  if (length(longCycles)==0) {
    return(NULL)
  } else {
    weightedPathSupport = vector(mode="numeric")
    wordForm = vector(mode="character")
    cnt = 0
    for (ii in 1:length(longCycles)) {
      for (jj in 1:length(longCycles[[ii]])) {
        p = longCycles[[ii]][[jj]]
        cnt = cnt+1
        weightedPathSupport[cnt] = sum(p)/length(p)
        if (grams==3) {
          wordForm[cnt] = paste(substr(names(p),2,2), sep="", collapse="")
        } else {
          if (grams != 4) stop("unknown value for grams")
          wordForm[cnt] = paste(paste(substr(names(p),2,2), sep="", collapse=""), 
                                substr(names(p)[length(names(p))],3,3), sep="")
        }
      }
    }
    pathdfr = data.frame(wordForm=wordForm, 
                         weightedPathSupport=weightedPathSupport, 
                         stringsAsFactors=FALSE)
    return(list(longPaths=longCycles, pathdfr=pathdfr))
  }
}
