make_C_and_T_matrices <-
  function(formula=~ Lexeme + Person + Number + Tense + Voice + Mood,
	   data=latin,          # default dataset is latin
           grams=3,            # 3 for triphones, 4 for n-phones
           seed=214           # seed for jitter on C matrix
           ) {         
    
    #require(ndl, quietly=TRUE)                  # makes orthoCoding available
    
    n = nrow(data)
    
    cues = ndl::orthoCoding(data$Word, grams=grams)  # requires ndl package
    
    Cues = strsplit(cues, "_")   # creates a list with for each word the n-phones
    uniqueCues = unique(unlist(Cues)) # vector of unique n-phones
    nCues = length(uniqueCues)        # number of unique n-phones
    C = matrix(0, n, nCues)           # set up C matrix
    rownames(C)=data$Word             # words are on rows
    colnames(C) = uniqueCues          # cues are on columns
    for (i in 1:nrow(data)) {         # 1s only for cues that are in word
      C[i,Cues[[i]]]=1
    }
    #set.seed(seed)                    # set seed for jitter
    #C = C + matrix(rnorm(nrow(C)*ncol(C), 0, 0.0005), nrow(C), ncol(C))
    
    classes = all.vars(formula)

    features = list()
    for (i in 1:length(classes)) {
      v = data[,classes[i]]
      v = v[!is.na(v)]
      features[[i]] = unique(v)
    }
    uniqueOutcomes = unlist(features)
    nOutcomes = length(uniqueOutcomes)

    Outcomes = list()
    for (i in 1:n){
      v = data[i, classes]
      v = v[!is.na(v)]
      Outcomes[[i]] = v
    }

    #outcomes = data$Lexomes           # the vector of lexomes
    #Outcomes = strsplit(outcomes, "_")  # a list with for each for its lexomes
    #uniqueOutcomes = unique(unlist(Outcomes)) # vector with unique lexomes
    #nOutcomes = length(uniqueOutcomes)  # number of unique lexomes
    T = matrix(0, n, nOutcomes)         # set up T matrix
    rownames(T) = data$Word             # words are on rows
    colnames(T) = uniqueOutcomes        # lexomes are on columns
    for (i in 1:nrow(data)) {           # 1s only for lexomes that are in word
      T[i,Outcomes[[i]]] = 1
    }

    #lexomes = strsplit(data$Lexomes, "_")
    base_forms = unique(data[,classes[1]])
    #n_base_forms = length(unique(base_forms))

    #inflectional_features = unique(unlist(lexomes))
    inflectional_features = uniqueOutcomes[!is.element(uniqueOutcomes, base_forms)]
    #n_inflectional_features = length(inflectional_features)


    
    return(list(matrices=list(C=C, 
                              T=T),
                datastructures=list(nCues=nCues, 
                                    nOutcomes=nOutcomes, 
                                    uniqueCues=uniqueCues, 
                                    uniqueOutcomes=uniqueOutcomes,
                                    Cues=Cues, 
                                    Outcomes=Outcomes,
                                    base_forms=base_forms,
                                    inflectional_features = inflectional_features)
    ))
  }
