semantic_neighbors <- 
  function(word="audiam", data=latin, n=8, md=m, cor=TRUE) {
    
    # a linear mapping will map a given fixed form vector
    # onto a fixed semantic vector; thus homophonic paradigm 
    # forms will all map onto the same semantic vector
    
    # recognition is evaluated as succesful if the predicted
    # semantic vector is closest to its targeted semantic vector
    
    # by default, the function returns the top 8 paradigm forms
    # that have the highest correlation with the predicted
    # semantic vector
  
    pos = which(rownames(md$Shat)==word)
    pos = pos[1]   # for homographs, there can be more than one position
    # obtain the correlation of its predicted semantic vector with
    # all targeted semantic vectors
    if (cor) {
      cors = cor(md$Shat[pos,], t(md$S))[1,] 
    } else {
      cossim = function(x,y) return(as.vector(x %*% y / sqrt(x%*%x * y%*%y)))
      x = md$Shat[pos,]
      mdSt = t(md$S)
      cors = vector(mode="numeric")
      for (j in 1:ncol(mdSt)) {
        cors[j] = cossim(x, mdSt[,j])
      }
      names(cors)=colnames(mdSt)
    }
    # get indices for reverse sort
    ordr = rev(order(cors))
    # get correlations for the reverse sort
    corsvec = cors[ordr]

    dfr = data.frame(form = names(corsvec)[1:n],
                     r = unname(corsvec)[1:n],
                     stringsAsFactors=FALSE)
    dfr = cbind(dfr, data[ordr[1:n], ])
    return(dfr)
  }
