\name{WpmWithLdl-package}
\alias{WpmWithLdl-package}
\alias{WpmWithLdl}
\docType{package}
\title{
\packageTitle{WpmWithLdl}
}
\description{
\packageDescription{WpmWithLdl}
}
\details{

The DESCRIPTION file:
\packageDESCRIPTION{WpmWithLdl}
\packageIndices{WpmWithLdl}
This package contains the datasets and functions for exploring linear mappings between form and meaning, as discussed in Baayen, Chuang & Blevins (2018).  }
\section{Data}{
\itemize{
\item \code{latin}: All finite inflected forms of 8 Latin verbs from the main four conjugation classes.
}
}
\section{Create matrices for form and meaning and mappings between them}{
\itemize{
\item \code{learn_mappings}: Learn mappings between form and meaning, and meaning and form.
\item \code{make_C_and_T_matrices}: Make C and T matrices for a language dataset, and return basic
  datastructures with cues and outcomes.
\item \code{semantic_space}: Simulates a semantic vector space.
}
}
\section{Comprehension}{
\itemize{
\item \code{accuracy_comprehension}: Calculate the accuracy of a mapping from form to meaning.
\item \code{semantic_neighbors}: Extract top correlations for homophones.
	}
}
\section{Production}{
	\itemize{
	\item \code{speak}: Generate a word form from a semantic vector.
\item \code{ngram2word}: Convert a character vector of n-grams (trigrams or quadrograms) into a word string.

}
}
\section{Visualising production}{
\itemize{
\item \code{graph_setup}: Creates the adjacency matrix and corresponding graph object for a dataset.
\item \code{graph_path}: Plots a graph which includes all vertices and edges of an adjacency matrix, with the path of a target word being highlighted.
\item \code{graph_topology_flect}: Graph topology with graphopt for inflectional functions.
\item \code{graph_topology_segments}: Graph topology with graphopt for segments.
\item \code{show_graph}: Plot a graph, by default with the graphopt layout.
\item \code{check_cycle}: Checks whether a cycle (triangle) has already been used in the path.
\item \code{long_cycles}: Attempts to find the best supported path in the trigram or 4-gram graph from a starting vertex to a final vertex, building on the \code{all_simple_paths} function from the \code{igraph} package.
	}
}
\author{
\packageAuthor{WpmWithLdl}

Maintainer: \packageMaintainer{WpmWithLdl}
}
\references{
Baayen, R. H., Y-Y Chuang, and Blevins, J. P. Inflectional morphology with linear mappings.  To appear in The Mental Lexicon, 2018.
}
\keyword{package}
\examples{
data(latin)
# create matrices for form and meaning as well as mapping between them, an
# adjacency matrix and a graph object, using triphones
m = learn_mappings(formula=~ Lexeme + Person + Number + Tense + Voice + Mood,
                   data = latin, 
                   grams = 3)
am = m$am #adjacency matrix
C = m$C #the form matrix
S = m$S #the semantic matrix

# show semantic space as heatmap
heatmap(cor(S))

}
