\name{accuracy_comprehension}
\alias{accuracy_comprehension}
\title{
Calculate the accuracy of a mapping from form to meaning.
}
\description{
Given the output \code{m} of \code{learn_mappings} and the dataset
on which \code{m} is based, this function calculates the closest
semantic vectors for the predicted semantic vectors, and bases
its accuracy score on the nearest neighbors.
}
\usage{
accuracy_comprehension(formula = ~ Lexeme + Person + Number + Tense + Voice + Mood, md = m, data = latin, cor = TRUE, epsilon = 0.05)
}
\arguments{
\item{formula}{
A formula specifying the lexeme and inflectional features that define a form's paradigm slot.
}
\item{md}{
A list, typically the output of \code{learn_mappings}.
}
\item{data}{
The dataset from which \code{m} was derived.
}
\item{cor}{
  A logical, if \code{TRUE}, the Pearson correlation is used to evaluate the similarity between vectors, otherwise, the cosine similarity is used.
}
\item{epsilon}{
Threshold value for accepting the synthesized form and its corresponding semantic vector as legitimate. Its support should not be less than the support for the originally selected paradigm slot minus epsilon. 
}
}
%\details{
%%  ~~ If necessary, more details than the description above ~~
%}
\value{
A list with components:
\item{dfr}{A data frame with statistics for each word in the data set.
}
\item{acc}{The proportion of words for which the predicted vector has the highest correlation (across all possible vectors) with the targeted vector.
}
\item{correlation}{
  The value of the cor directive (TRUE/FALSE).
}
}
%\references{
%}
\author{
R. H. Baayen
}
%\note{
%%  ~~further notes~~
%}
%
%% ~Make other sections like Warning with \section{Warning }{....} ~
%
%\seealso{
%\code{accuracyT}, \code{evaluate}
%}
%\examples{
%\dontrun{
%data(polish)
%n = nrow(polish)
%polish$Lexomes = paste(polish$Lexeme, polish$Case, polish$Number, sep="_")
%polish$Word = polish$Phonology
%lexomes = strsplit(polish$Lexomes, "_")
%verbs = unique(unlist(sapply(lexomes, FUN=function(v)v[1])))
%nverbs = length(verbs)
%inflections = unique(unlist(lexomes))
%inflections = inflections[!is.element(inflections, verbs)]
%ninflections = length(inflections)
%ms3 = makeMatrices(grams=3, data=polish)
%C = ms3$matrices$C
%nCues = ms3$datastructures$nCues         # number of triphones
%nOutcomes = ms3$datastructures$nOutcomes # number of features
%Cues = ms3$datastructures$Cues           # list with for each word its triphones
%Outcomes = ms3$datastructures$Outcomes
%set.seed(217)
%S = semantic_space(nrows=nrow(C), ncols=ncol(C), data=polish)
%H = C \%*\% ginv(t(C) \%*\% C) \%*\% t(C)  
%Shat = H \%*\% S
%res = accuracy(Shat, S)
%res$accuracy
%}
%}
\examples{
data(latin)
m = learn_mappings(formula = ~ Lexeme + Person + Number + Tense + Voice + Mood,
                   data = latin, 
                   grams = 3)
acc = accuracy_comprehension(md = m, data = latin)
acc$acc
}
\keyword{misc}
