\name{graph_setup}
\alias{graph_setup}
\title{
graph_setup creates the adjacency matrix and corresponding graph object for a dataset.
}
\description{
From the \code{Cues} list, which provides for each word in a dataset the n-grams it contains, an adjacency matrix for all words in that dataset is created.  Using \code{igraph}, a graph object is created.  The function returns both the adjacency matrix and the graph object.
}
\usage{
graph_setup(nCues, Cues, uniqueCues)
}
\arguments{
\item{nCues}{
The number of different cues (n-grams) in a given dataset (as produced by \code{make_C_and_T_matrices})
}
\item{Cues}{
A list with for each word in a dataset, a vector with the n-grams for that word (as produced by \code{make_C_and_T_matrices})
}
\item{uniqueCues}{
A character vector with the unique form cues (as produced by \code{make_C_and_T_matrices})
}
}
%\details{
%%  ~~ If necessary, more details than the description above ~~
%}
\value{
A list with two components:
\item{am}{The adjacency matrix derived from Cues}
\item{am.g}{The corresponding \code{igraph} object}
}
%\references{
%% ~put references to the literature/web site here ~
%}
\author{
R. H. Baayen, M. Heitmeier
}
%\note{
%%  ~~further notes~~
%}
%
%% ~Make other sections like Warning with \section{Warning }{....} ~
%
%\seealso{
%See also \code{\link{help}}, ~~~
%}
\examples{
data(latin)
# produce lists of cues, outcomes and unique outcomes
ms3 = make_C_and_T_matrices(formula=~ Lexeme + Person + Number + Tense + Voice + Mood, 
                            data=latin, grams=3)
nCues = ms3$datastructures$nCues
Cues = ms3$datastructures$Cues
uniqueCues = ms3$datastructures$uniqueCues

gsu = graph_setup(nCues, Cues, uniqueCues)
}
\keyword{misc}
