\name{graph_topology_flect}
\alias{graph_topology_flect}
\title{
Graph topology with graphopt for inflectional functions.
}
\description{
The graphopt algorithm is used to organize triphones in a 2-D plane.  The user can select which inflectional functions are to be highlighted in the plot.
}
\usage{
graph_topology_flect(lexomes = c("past", "future", "perfect", "pluperfect", "present"), 
					class = "Tense", 
					mycolors = c("steelblue2", "indianred", "darkgreen", "gray70", "cyan"), 
					data = latin, 
					am = am, 
					seed = 315)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
\item{lexomes}{
A vector specifying the lexomes (inflectional functions) to be highlighted in the plot.
}
\item{class}{
The specific class (column name in the dataset) relevant for the lexomes to be plotted.
}
\item{mycolors}{
A vector of color names to differentiate between lexomes in the plot.
}
\item{data}{
The dataset under analysis.
}
\item{am}{
Adjacency matrix of full dataset (as produced by \code{graph_setup}).
}
\item{seed}{
The seed can be specified to change the default plot orientation.
}
}
\details{
Only those triphones that uniquely subserve a specific lexome are highlighted.
}
\value{
A plot is shown on the output device.
}
%\references{
%%% ~put references to the literature/web site here ~
%}
\author{
R. H. Baayen, M. Heitmeier
}
%\note{
%%  ~~further notes~~
%}
%
%% ~Make other sections like Warning with \section{Warning }{....} ~
\seealso{
See also \code{\link{graph_topology_segments}}.
}
\examples{
data(latin)
library(igraph)

# produce lists of cues, outcomes and unique outcomes
ms3 = make_C_and_T_matrices(formula = ~ Lexeme + Person + Number + Tense + Voice + Mood, 
                            data=latin, grams=3)
C = ms3$matrices$C
T = ms3$matrices$T
nCues = ms3$datastructures$nCues
nOutcomes = ms3$datastructures$nOutcomes
Cues = ms3$datastructures$Cues
Outcomes = ms3$datastructures$Outcomes
uniqueCues = ms3$datastructures$uniqueCues
uniqueOutcomes = ms3$datastructures$uniqueOutcomes

# produce the adjacency matrix
gsu = graph_setup(nCues, Cues, uniqueCues)
am = gsu$am
am.g = gsu$am.g

# show plot
graph_topology_flect(data=latin, am=am)
}
\keyword{hplot}
