\name{graph_topology_segments}
\alias{graph_topology_segments}
\title{
Graph topology with graphopt for segments.
}
\description{
The graphopt algorithm is used to organize triphones in a 2-D plane.  The user can select which segments (center elements of triphones) are to be highlighted in the plot.
}
\usage{
graph_topology_segments(segments = c("i", "e", "a", "o", "u"), 
                        mycolors = c("steelblue2", "indianred", "darkgreen", "gray70", "cyan"), 
                        am = am,
                        C = C,
                        seed = 315)

}
\arguments{
\item{segments}{
The segments to be highlighted. By default, the vowels of Latin.
}
\item{mycolors}{
A character vector of color names, of the same length as the length of the
vector with segments.
}
\item{am}{
Adjacency matrix for full dataset (as produced by \code{graph_setup}).
}
\item{C}{
The cue matrix \code{C} (as produced by \code{make_C_and_T_matrices}).
}
\item{seed}{
The seed can be specified to change the default plot orientation
}
}
\details{
Only those triphones that uniquely subserve a specific segment are highlighted.
}
\value{
A plot is shown on the output device.
}
%\references{
%% ~put references to the literature/web site here ~
%}
\author{
R. H. Baayen
}
%\note{
%%  ~~further notes~~
%}
\seealso{
See also as \code{\link{graph_topology_flect}}.
}
\examples{
data(latin)
library(igraph)
n = nrow(latin)

# produce lists of cues, outcomes and unique outcomes
ms3 = make_C_and_T_matrices(formula=~ Lexeme + Person + Number + Tense + Voice + Mood, data=latin, grams=3)
C = ms3$matrices$C
T = ms3$matrices$T
nCues = ms3$datastructures$nCues
nOutcomes = ms3$datastructures$nOutcomes
Cues = ms3$datastructures$Cues
Outcomes = ms3$datastructures$Outcomes
uniqueCues = ms3$datastructures$uniqueCues
uniqueOutcomes = ms3$datastructures$uniqueOutcomes

# produce the adjacency matrix
gsu = graph_setup(nCues, Cues, uniqueCues)
am = gsu$am
am.g = gsu$am.g

# show plot
graph_topology_segments(am=am, C=C)
}
\keyword{hplot}
