\name{learn_mappings}
\alias{learn_mappings}
\title{
Learn mappings between form and meaning, and meaning and form.
}
\description{
Given input data and the form units to work with (trigrams or quadrograms), 
matrices for form and meaning are derived as well as the mappings between
them.  In addition, the adjacency matrix and corresponding graph object
are calculated.
}
\usage{
learn_mappings(formula=~ Lexeme + Person + Number + Tense + Voice + Mood, 
               data = latin, 
               grams = 3, 
               stdev_inflectional_semantic_vectors = 4,
               seed_for_S=217)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{formula}{
    A formula specifying the classes (column names of \code{data}) to be used to construct semantic vectors; the first class mentioned should refer to the content lexome of an inflected form. 
  }
  \item{data}{
A dataset with word forms and their lexomes.
}
  \item{grams}{
Set to 3 for trigrams/triphones and to 4 for quadrograms/quadrophones.
}

  \item{stdev_inflectional_semantic_vectors}{ 
  Standard deviation for \code{rnorm} used to generate a semantic vector for an inflectional feature.  
}
  \item{seed_for_S}{
Seed set before calculating the matrix with simulated semantic vectors.
}
}
%\details{
%%  ~~ If necessary, more details than the description above ~~
%}
\value{
A list with components
\item{am }{Adjacency matrix for the full dataset.}
\item{am.g }{Graph object corresponding to adjacency matrix.}
\item{C }{A words by n-gram form matrix.}
\item{S }{A words by features semantic matrix.}
\item{Shat }{Estimated semantic matrix given the form matrix.}
\item{Bcomp }{The matrix with coefficients to derive Shat.}
\item{Bprod }{The matrix with coefficients to derive Chat.}
\item{Chat }{Estimated form matrix given the semantic matrix.}
\item{ms3 }{Output of \code{make_C_and_T_matrices}, which also provides additional data structures.}
}
%\references{
%% ~put references to the literature/web site here ~
%}
\author{
R. H. Baayen
}
\examples{
data(latin)
m = learn_mappings(formula=~ Lexeme + Person + Number + Tense + Voice + Mood,
                   data = latin, 
                   grams = 3)
head(m$C, 2)
}
%\note{
%%  ~~further notes~~
%}
%
%% ~Make other sections like Warning with \section{Warning }{....} ~
%
%\seealso{
%% ~~objects to See Also as \code{\link{help}}, ~~~
%}
%\examples{
%##---- Should be DIRECTLY executable !! ----
%##-- ==>  Define data, use random,
%##--	or do  help(data=index)  for the standard data sets.
%}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{misc}
