\name{long_cycles}
\alias{long_cycles}
\title{
A function that attempts to find the best supported path in the trigram or 4-gram graph from a starting vertex to a final vertex, building on the \code{all_simple_paths} function from the \code{igraph} package.
}
\description{
This function checks for cycles from a vertex in word \code{i}'s path back into an earlier vertex in that path.  It first calculates all simple paths starting with the word's initial n-gram, then checks for cycles in those paths, and for every instance found, it then completes the path to the word-final trigram.  From this set of paths, only those paths are retained for which all edges have positive support from \code{Chat}.  The function returns a list with two components, a list of paths, and a dataframe with the word form and its weighted path support.
}
\usage{
long_cycles(i = 1, Chat, am, am.g, Cues, grams = 3)
}
\arguments{
\item{i}{
row index in the current data set (equivalently, index in \code{Cues})
}
\item{Chat}{
The estimated form matrix C.
}
\item{am}{
The adjacency matrix for the full data set.
}
\item{am.g}{
The graph corresponding to \code{am}.
}
\item{Cues}{
A list specifying, for each word form, its component n-grams.
}
\item{grams}{
By default, 3-grams are used, but 4-grams are also supported.
}
}
%\details{
%}
\value{
A list with two components:
\item{longPaths}{a list with the paths with long cycles}
\item{pathdfr}{a data frame with columns \code{wordForm} specifying the word forms, and \code{weightedPathSupport} specyfing the weighted path support for that word}
If no cycles are found, the function returns \code{NULL}.
}
\author{
R. H. Baayen
}
\seealso{
See also \code{\link{check_cycle}}.
}
%\examples{
%##---- Should be DIRECTLY executable !! ----
%##-- ==>  Define data, use random,
%##--	or do  help(data=index)  for the standard data sets.
%}
\keyword{misc}
