\name{semantic_neighbors}
\alias{semantic_neighbors}
\title{
Extract correlation of semantic vectors for the top best supported competitors.
}
\description{
Given a word form, this function calculates the correlation of the predicted semantic vector given this word's form vector with the word's targeted (observed) semantic vector.  By default, correlations are shown for the 8 most strongly correlated competitors.  
}
\usage{
semantic_neighbors(word="audiam", data="latin", n=8, md=m, cor=TRUE)
}
\arguments{
  \item{word}{
    A word form.
}
\item{data}{
    The data set.
}
\item{n}{
    The number of top \code{n} most correlated words to be returned.
}
\item{md}{
    The output of \code{learn_matrices}.
}
\item{cor}{
    Logical, if \code{TRUE}, the Pearson correlation is used to evaluate vector similarity, otherwise, the cosine similarity is used.
}
}
\details{
This function is especially useful for tracing model performance for homophones. Note that a linear mapping will associate a given form vector, which is the exactly the same for each member of a set of homophones, onto one and the same fixed semantic vector.  Thus, in the output of this function, each homophone will have its own row.  Ideally, one homophone will have the largest correlation of all semantic competitors.
}
\value{
A data frame with forms (\code{form}), correlations (\code{r}), and lexomes (\code{lexomes}).
}
%\references{
%}
\author{
R. H. Baayen
}
%\note{
%%  ~~further notes~~
%}
%
%% ~Make other sections like Warning with \section{Warning }{....} ~
%
%\seealso{
%\code{accuracyT}, \code{evaluate}
%}
\examples{
data(latin)
m = learn_mappings(~ Lexeme + Person + Number + Tense + Voice + Mood,
                   data = latin, 
                   grams = 3)
# show the top 5 competitors of the homophone "audiam"

h = semantic_neighbors(word = "audiam", n = 5, data = latin, md = m)
}
\keyword{misc}
