\name{speak}
\alias{speak}
\title{
Generate a word form from a semantic vector.
}
\description{
This function generates a word form given a semantic vector, indexed by
the row number of the word in the dataset.
}
\usage{
speak(pos = 1, grams = 3, threshold = 0.1, amat = am, data = latin, C = C, S = S, Bcomp = B, Bprod = NULL, Chat = Chat, s = NULL, include_long_cycles=FALSE, m = NULL, tolerance = 0, returnlist = FALSE, returnnet = FALSE, returngraph = FALSE)
}
\arguments{
\item{pos}{
Row index of the word to be produced in the current data set.
}
\item{grams}{
By default, 3-grams are used, but 4-grams are also supported.
}
\item{threshold}{
Threshold for thinning the graph: only vertices with support from the semantic mapping that exceeds the threshold are included in the thinned graph.  }
\item{amat}{
The adjacency matrix for the full data set (as produced by \code{graph_setup}).
}
\item{data}{
The dataset (by default, \code{latin}).
}
\item{C}{
Form matrix with words on rows and trigrams (4-grams) on columns (as produced by \code{make_C_and_T_matrices} and \code{learn_mappings}).
}
\item{S}{
Semantic matrix with words on rows and semantic features on columns (as produced by \code{semantic_space}).
}
\item{Bcomp}{
Matrix (number of cues by number of cues) that maps a form vector onto a semantic vector (as produced by \code{learn_mappings}).
}
\item{Bprod}{
Matrix (number of semantic features by number of semantic features) that maps a semantic vector onto a form vector (as produced by \code{learn_mappings}).
}
\item{Chat}{
Matrix with predicted form vectors given C and S (as produced by \code{learn_mappings}). 
}
\item{s}{
Semantic vector (specified in combination with \code{Bprod}), for which a form vector and form path in the triphone (or 4-phone) graph is to be calculated for
analysis by synthesis.
}
\item{include_long_cycles}{
  If \code{TRUE}, cycles with more than 3 edges are searched for in addition to cycles of length 2 and length 3.
}
\item{m}{
  Output of \code{learn_matrices}, should be specified if \code{include_long_cycles==TRUE}.
}
\item{tolerance}{
A real specifying how far off the support for a candidate can be from the maximum support.  For German, set \code{tolerance = 0.1}, for Latin, leave it at its default value, 0.
}
\item{returnlist}{
If TRUE, a list with as elements named vectors, one for each word candidate, with vertex supports as values and the names of the vertices as names.
}
\item{returnnet}{
If TRUE, return the adjacency matrix of the trimmed network.
}
\item{returngraph}{
If TRUE, return the graph object of the trimmed network.
}
}
%\details{
%}
\value{
A list with components:
\item{word}{the word form to be produced}
\item{prediction}{character vector with the word form selected by the algorithm for production (note: there can be several equivalent candidates)}
\item{candidates}{the set of word forms from the the prediction set is taken}
\item{pos}{the row index of the word form to be produced in the dataset}
\item{length_weakest_link_ratio}{the ratio of path length to the value of the
  weakest link (the vertex with least support)}
\item{cors}{named vector with the correlations of the semantic vectors of the candidates with the semantic vector that is to be realized in production}
}
%\references{
%% ~put references to the literature/web site here ~
%}
\author{
R. H. Baayen
}
\note{
For datasets such as \code{latin}, there is no uncertainty about the proper initial n-gram.  For more realistic data, evaluation will require an additional loop over all positively supported initial n-grams.  See the annotated code for further details.
}
\seealso{
See Also \code{\link{check_cycle}}, \code{\link{show_graph}}.
}
%\examples{
%##---- Should be DIRECTLY executable !! ----
%##-- ==>  Define data, use random,
%##--	or do  help(data=index)  for the standard data sets.
%}
\examples{
data(latin)
# create matrices for form (C) and meaning (S) as well as mappings between them (Bcomp, Bprod), an
# adjacency matrix (am) and a graph object
m = learn_mappings(formula = ~ Lexeme + Person + Number + Tense + Voice + Mood,
                   data = latin, 
                   grams = 3)
am = m$am
C = m$C
S = m$S
Bcomp = m$Bcomp
Chat = m$Chat
s = speak(amat = am, C = C, S = S, Bcomp = Bcomp, Chat = Chat)
}
\keyword{misc}
